@@ -10,7 +10,7 @@ use Plack::Util::Accessor qw/
     view_root
 /;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub prepare_app {
     my ($self) = @_;
@@ -60,7 +60,8 @@ sub _add_link {
 
     for my $lib_path (@{$self->lib}) {
         next if $lib_path eq '.';
-        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]([^\.]+\.[^\s]+)\s+line\s+(\d+))!_link_html($1, $2, $3)!eg;
+        $lib_path =~ s!/!\\!g if $^O eq 'MSWin32';
+        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]+([^\.]+\.[^\s]+)\s+line\s+(\d+))!_link_html($1, $2, $3)!eg;
     }
 }
 
@@ -124,7 +125,7 @@ see more configurations on L<Plack::Middleware::StackTrace>
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1455845733"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1455845733&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1455865821"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1455865821&branch=master"/></a>
 
 =end html
 
